@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: start_project.py 11464 2019-04-17 06:34:50Z Lavender $
+# $Id: start_project.py 11485 2019-04-24 03:19:25Z Lavender $
 #
 # Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-17 15:34:50 +0900 (週三, 17 四月 2019) $
-# $Revision: 11464 $
+# $Date: 2019-04-24 12:19:25 +0900 (週三, 24 四月 2019) $
+# $Revision: 11485 $
 
 import os
 import sys
@@ -113,9 +113,9 @@ class Command(BaseCommand):
         with open(os.path.join(commandPath, "__init__.py"), 'w') as f:
             pass
             
-        renderFile('scaffold/Deploy.py', commandPath, 'deploy.py')
+        renderFile('scaffold/Deploy.txt', commandPath, 'deploy.py')
 
-        # Settings.py ----------------------------------------------------------
+        # Settings.txt ----------------------------------------------------------
         with open(settingPath, 'r') as setting:
             content = setting.read()
 
@@ -123,20 +123,21 @@ class Command(BaseCommand):
         context = {
             "year": datetime.date.today().year,
         }
-        temp = get_template('scaffold/HeaderTemplate.py')
+        temp = get_template('scaffold/HeaderTemplate.txt')
         header = temp.render(context)
         content = header + content
 
         # debug & mode
         context = {
             "name": name.lower(),
+            "version": IUNO_VERSION,
         }
-        temp = get_template('scaffold/DebugTemplate.py')
+        temp = get_template('scaffold/DebugTemplate.txt')
         debug = temp.render(context)
         content = content.replace('DEBUG = True', debug)
 
         # allow host
-        temp = get_template('scaffold/AllowHostTemplate.py')
+        temp = get_template('scaffold/AllowHostTemplate.txt')
         host = temp.render(context)
         content = content.replace('ALLOWED_HOSTS = []', host)
 
@@ -144,49 +145,49 @@ class Command(BaseCommand):
         context = {
             "name": name,
         }
-        temp1 = get_template('scaffold/InstalledApps.py').render()
+        temp1 = get_template('scaffold/InstalledApps.txt').render()
         temp2 = get_template(
-            'scaffold/InstalledAppsTemplate.py').render(context)
+            'scaffold/InstalledAppsTemplate.txt').render(context)
         content = content.replace(temp1, temp2)
 
         # db & static
-        temp = get_template('scaffold/Database.py')
+        temp = get_template('scaffold/Database.txt')
         database = temp.render()
         content = content.replace(database, '')
 
-        temp = get_template('scaffold/Static.py')
+        temp = get_template('scaffold/Static.txt')
         static = temp.render()
         content = content.replace(static, '')
 
-        temp = get_template('scaffold/TimeZone.py')
+        temp = get_template('scaffold/TimeZone.txt')
         timeZone = temp.render()
         content = content.replace(timeZone, '')
         
         # template & middleware & auth password
-        temp = get_template('scaffold/Templates.py')
+        temp = get_template('scaffold/Templates.txt')
         templates = temp.render()
         content = content.replace(templates, '')
         
-        temp = get_template('scaffold/Middleware.py')
+        temp = get_template('scaffold/Middleware.txt')
         middleware = temp.render()
         content = content.replace(middleware, '')
         
-        temp = get_template('scaffold/Auth.py')
+        temp = get_template('scaffold/Auth.txt')
         auth = temp.render()
         content = content.replace(auth, '')
         
         # wsgi & root urlconf
-        temp = get_template('scaffold/Wsgi.py')
+        temp = get_template('scaffold/Wsgi.txt')
         wsgi = temp.render(context)
         content = content.replace(wsgi, '')
         
-        temp = get_template('scaffold/Urlconf.py')
+        temp = get_template('scaffold/Urlconf.txt')
         urlconf = temp.render(context)
         content = content.replace(urlconf, '')
         
         
         # Footer
-        temp = get_template('scaffold/FooterTemplate.py')
+        temp = get_template('scaffold/FooterTemplate.txt')
         footer = temp.render()
         content = content.strip() + '\n' + footer
 
@@ -195,12 +196,12 @@ class Command(BaseCommand):
                 setting.write(six.b(utf8(content.replace('\r\n', '\n'))))
             else:
                 setting.write(content.replace('\r\n', '\n').encode())
-        # Urls.py --------------------------------------------------------------
+        # Urls.txt --------------------------------------------------------------
         with open(urlPath, 'r') as url:
             content = url.read()
 
-        temp1 = get_template('scaffold/Urls.py').render()
-        temp2 = get_template('scaffold/UrlsTemplate.py').render()
+        temp1 = get_template('scaffold/Urls.txt').render()
+        temp2 = get_template('scaffold/UrlsTemplate.txt').render()
         content = content.replace(temp1, temp2)
 
         with open(urlPath, 'w') as url:
